{% extends "base.html" %}
{% load i18n %}
{% load config %}
{% load crispy_forms_tags %}
{% block page_title %}
    {% vocabulary "assignment" as v_assignment %}
    <div class="page-title col-md-12">
        <h3>
            {% blocktrans %}Angemeldete/n/s {{ v_assignment }} beantworten{% endblocktrans %}
        </h3>
    </div>
{% endblock %}
{% block content %}
    <div class="col-md-12 mb-4">
        {% trans "Von:" %} {{ assignment_request.member }}<br>
        {% trans "Beschreibung:" %} {{ assignment_request.description }}<br>
        {% trans "Am:" %} {{ assignment_request.job_time|date:"d.m.Y H:i" }}
    </div>
    <div class="col-md-12 mb-4">
        <form action="" method="post" id="request_assignment">
            {% crispy form %}
        </form>
    </div>
{% endblock %}
