# Generated by Django 2.2.4 on 2019-10-22 21:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('juntagrico_assignment_request', '0001_squashed_0006_auto_20191020_2203'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentrequest',
            name='assignment',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='juntagrico.Assignment'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='activityarea',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='juntagrico.ActivityArea', verbose_name='Tätigkeitsbereich'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='approver',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='Referenz', to='juntagrico.Member', verbose_name='Abgesprochen mit'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='assignment',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='juntagrico.Assignment', verbose_name='Arbeitseinsatz'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='juntagrico.Member', verbose_name='Mitglied'),
        ),
    ]
